import typing

import android.icu.text
import android.icu.util
import java
import java.chaquopy
import java.lang
import java.util

class UCharacter(UCharacterEnums.ECharacterCategory, UCharacterEnums.ECharacterDirection):
    FOLD_CASE_DEFAULT: typing.ClassVar[int] = ...
    FOLD_CASE_EXCLUDE_SPECIAL_I: typing.ClassVar[int] = ...
    MAX_CODE_POINT: typing.ClassVar[int] = ...
    MAX_HIGH_SURROGATE: typing.ClassVar[str] = ...
    MAX_LOW_SURROGATE: typing.ClassVar[str] = ...
    MAX_RADIX: typing.ClassVar[int] = ...
    MAX_SURROGATE: typing.ClassVar[str] = ...
    MAX_VALUE: typing.ClassVar[int] = ...
    MIN_CODE_POINT: typing.ClassVar[int] = ...
    MIN_HIGH_SURROGATE: typing.ClassVar[str] = ...
    MIN_LOW_SURROGATE: typing.ClassVar[str] = ...
    MIN_RADIX: typing.ClassVar[int] = ...
    MIN_SUPPLEMENTARY_CODE_POINT: typing.ClassVar[int] = ...
    MIN_SURROGATE: typing.ClassVar[str] = ...
    MIN_VALUE: typing.ClassVar[int] = ...
    NO_NUMERIC_VALUE: typing.ClassVar[float] = ...
    REPLACEMENT_CHAR: typing.ClassVar[int] = ...
    SUPPLEMENTARY_MIN_VALUE: typing.ClassVar[int] = ...
    TITLECASE_NO_BREAK_ADJUSTMENT: typing.ClassVar[int] = ...
    TITLECASE_NO_LOWERCASE: typing.ClassVar[int] = ...
    @staticmethod
    def charCount(cp: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointAt(seq: java.lang.CharSequence, index: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointAt(text: java.chaquopy.JavaArrayJChar, index: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointAt(text: java.chaquopy.JavaArrayJChar, index: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointBefore(seq: java.lang.CharSequence, index: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointBefore(text: java.chaquopy.JavaArrayJChar, index: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointBefore(text: java.chaquopy.JavaArrayJChar, index: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointCount(text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def codePointCount(text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def digit(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def digit(ch: int | java.jint | java.lang.Integer, radix: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def foldCase(ch: int | java.jint | java.lang.Integer, options: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def foldCase(ch: int | java.jint | java.lang.Integer, defaultmapping: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    @typing.overload
    @staticmethod
    def foldCase(str: str | java.lang.String, options: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def foldCase(str: str | java.lang.String, defaultmapping: bool | java.jboolean | java.lang.Boolean, /) -> str: ...
    @staticmethod
    def forDigit(digit: int | java.jint | java.lang.Integer, radix: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getAge(ch: int | java.jint | java.lang.Integer, /) -> android.icu.util.VersionInfo: ...
    @staticmethod
    def getBidiPairedBracket(c: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getCharFromExtendedName(name: str | java.lang.String, /) -> int: ...
    @staticmethod
    def getCharFromName(name: str | java.lang.String, /) -> int: ...
    @staticmethod
    def getCharFromNameAlias(name: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def getCodePoint(char16: str | java.jchar | java.lang.Character, /) -> int: ...
    @typing.overload
    @staticmethod
    def getCodePoint(lead: str | java.jchar | java.lang.Character, trail: str | java.jchar | java.lang.Character, /) -> int: ...
    @typing.overload
    @staticmethod
    def getCodePoint(lead: int | java.jint | java.lang.Integer, trail: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getCombiningClass(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getDirection(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getDirectionality(cp: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getExtendedName(ch: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getExtendedNameIterator() -> android.icu.util.ValueIterator: ...
    @staticmethod
    def getHanNumericValue(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getIntPropertyMaxValue(type: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getIntPropertyMinValue(type: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getIntPropertyValue(ch: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getMirror(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def getName(ch: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def getName(s: str | java.lang.String, separator: str | java.lang.String, /) -> str: ...
    @staticmethod
    def getNameAlias(ch: int | java.jint | java.lang.Integer, /) -> str | None: ...
    @staticmethod
    def getNameIterator() -> android.icu.util.ValueIterator: ...
    @staticmethod
    def getNumericValue(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getPropertyEnum(propertyAlias: java.lang.CharSequence, /) -> int: ...
    @staticmethod
    def getPropertyName(property: int | java.jint | java.lang.Integer, nameChoice: int | java.jint | java.lang.Integer, /) -> str | None: ...
    @staticmethod
    def getPropertyValueEnum(property: int | java.jint | java.lang.Integer, valueAlias: java.lang.CharSequence, /) -> int: ...
    @staticmethod
    def getPropertyValueName(property: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, nameChoice: int | java.jint | java.lang.Integer, /) -> str | None: ...
    @staticmethod
    def getType(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getTypeIterator() -> android.icu.util.RangeValueIterator: ...
    @staticmethod
    def getUnicodeNumericValue(ch: int | java.jint | java.lang.Integer, /) -> float: ...
    @staticmethod
    def getUnicodeVersion() -> android.icu.util.VersionInfo: ...
    @typing.overload
    @staticmethod
    def hasBinaryProperty(ch: int | java.jint | java.lang.Integer, property: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def hasBinaryProperty(s: java.lang.CharSequence, property: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isBMP(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isBaseForm(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isDefined(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isDigit(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isHighSurrogate(ch: str | java.jchar | java.lang.Character, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isHighSurrogate(codePoint: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isISOControl(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isIdentifierIgnorable(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isJavaIdentifierPart(cp: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isJavaIdentifierStart(cp: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isLegal(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isLegal(str: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isLetter(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isLetterOrDigit(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isLowSurrogate(ch: str | java.jchar | java.lang.Character, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isLowSurrogate(codePoint: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isLowerCase(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isMirrored(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isPrintable(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isSpaceChar(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isSupplementary(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isSupplementaryCodePoint(cp: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isSurrogatePair(high: str | java.jchar | java.lang.Character, low: str | java.jchar | java.lang.Character, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isSurrogatePair(high: int | java.jint | java.lang.Integer, low: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isTitleCase(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isUAlphabetic(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isULowercase(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isUUppercase(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isUWhiteSpace(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isUnicodeIdentifierPart(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isUnicodeIdentifierStart(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isUpperCase(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isValidCodePoint(cp: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isWhitespace(ch: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def offsetByCodePoints(text: java.lang.CharSequence, index: int | java.jint | java.lang.Integer, codePointOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def offsetByCodePoints(text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, index: int | java.jint | java.lang.Integer, codePointOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def toChars(cp: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJChar: ...
    @typing.overload
    @staticmethod
    def toChars(cp: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJChar, dstIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def toCodePoint(high: str | java.jchar | java.lang.Character, low: str | java.jchar | java.lang.Character, /) -> int: ...
    @typing.overload
    @staticmethod
    def toCodePoint(high: int | java.jint | java.lang.Integer, low: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def toLowerCase(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def toLowerCase(str: str | java.lang.String, /) -> str: ...
    @typing.overload
    @staticmethod
    def toLowerCase(locale: android.icu.util.ULocale, str: str | java.lang.String, /) -> str: ...
    @typing.overload
    @staticmethod
    def toLowerCase(locale: java.util.Locale, str: str | java.lang.String, /) -> str: ...
    @staticmethod
    def toString(ch: int | java.jint | java.lang.Integer, /) -> str | None: ...
    @typing.overload
    @staticmethod
    def toTitleCase(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def toTitleCase(str: str | java.lang.String, breakiter: android.icu.text.BreakIterator, /) -> str: ...
    @typing.overload
    @staticmethod
    def toTitleCase(locale: android.icu.util.ULocale, str: str | java.lang.String, titleIter: android.icu.text.BreakIterator, /) -> str: ...
    @typing.overload
    @staticmethod
    def toTitleCase(locale: java.util.Locale, str: str | java.lang.String, breakiter: android.icu.text.BreakIterator, /) -> str: ...
    @typing.overload
    @staticmethod
    def toTitleCase(locale: android.icu.util.ULocale, str: str | java.lang.String, titleIter: android.icu.text.BreakIterator, options: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def toTitleCase(locale: java.util.Locale, str: str | java.lang.String, titleIter: android.icu.text.BreakIterator, options: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def toUpperCase(ch: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def toUpperCase(str: str | java.lang.String, /) -> str: ...
    @typing.overload
    @staticmethod
    def toUpperCase(locale: android.icu.util.ULocale, str: str | java.lang.String, /) -> str: ...
    @typing.overload
    @staticmethod
    def toUpperCase(locale: java.util.Locale, str: str | java.lang.String, /) -> str: ...

    class WordBreak(java.lang.Object):
        ALETTER: typing.ClassVar[int] = ...
        CR: typing.ClassVar[int] = ...
        DOUBLE_QUOTE: typing.ClassVar[int] = ...
        EXTEND: typing.ClassVar[int] = ...
        EXTENDNUMLET: typing.ClassVar[int] = ...
        E_BASE: typing.ClassVar[int] = ...
        E_BASE_GAZ: typing.ClassVar[int] = ...
        E_MODIFIER: typing.ClassVar[int] = ...
        FORMAT: typing.ClassVar[int] = ...
        GLUE_AFTER_ZWJ: typing.ClassVar[int] = ...
        HEBREW_LETTER: typing.ClassVar[int] = ...
        KATAKANA: typing.ClassVar[int] = ...
        LF: typing.ClassVar[int] = ...
        MIDLETTER: typing.ClassVar[int] = ...
        MIDNUM: typing.ClassVar[int] = ...
        MIDNUMLET: typing.ClassVar[int] = ...
        NEWLINE: typing.ClassVar[int] = ...
        NUMERIC: typing.ClassVar[int] = ...
        OTHER: typing.ClassVar[int] = ...
        REGIONAL_INDICATOR: typing.ClassVar[int] = ...
        SINGLE_QUOTE: typing.ClassVar[int] = ...
        WSEGSPACE: typing.ClassVar[int] = ...
        ZWJ: typing.ClassVar[int] = ...

    class VerticalOrientation(java.lang.Object):
        ROTATED: typing.ClassVar[int] = ...
        TRANSFORMED_ROTATED: typing.ClassVar[int] = ...
        TRANSFORMED_UPRIGHT: typing.ClassVar[int] = ...
        UPRIGHT: typing.ClassVar[int] = ...

    class UnicodeBlock(java.lang.Character.Subset):
        ADLAM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ADLAM_ID: typing.ClassVar[int] = ...
        AEGEAN_NUMBERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        AEGEAN_NUMBERS_ID: typing.ClassVar[int] = ...
        AHOM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        AHOM_ID: typing.ClassVar[int] = ...
        ALCHEMICAL_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ALCHEMICAL_SYMBOLS_ID: typing.ClassVar[int] = ...
        ALPHABETIC_PRESENTATION_FORMS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ALPHABETIC_PRESENTATION_FORMS_ID: typing.ClassVar[int] = ...
        ANATOLIAN_HIEROGLYPHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ANATOLIAN_HIEROGLYPHS_ID: typing.ClassVar[int] = ...
        ANCIENT_GREEK_MUSICAL_NOTATION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ANCIENT_GREEK_MUSICAL_NOTATION_ID: typing.ClassVar[int] = ...
        ANCIENT_GREEK_NUMBERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ANCIENT_GREEK_NUMBERS_ID: typing.ClassVar[int] = ...
        ANCIENT_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ANCIENT_SYMBOLS_ID: typing.ClassVar[int] = ...
        ARABIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_EXTENDED_A_ID: typing.ClassVar[int] = ...
        ARABIC_EXTENDED_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_EXTENDED_B_ID: typing.ClassVar[int] = ...
        ARABIC_EXTENDED_C: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_EXTENDED_C_ID: typing.ClassVar[int] = ...
        ARABIC_ID: typing.ClassVar[int] = ...
        ARABIC_MATHEMATICAL_ALPHABETIC_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_MATHEMATICAL_ALPHABETIC_SYMBOLS_ID: typing.ClassVar[int] = ...
        ARABIC_PRESENTATION_FORMS_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_PRESENTATION_FORMS_A_ID: typing.ClassVar[int] = ...
        ARABIC_PRESENTATION_FORMS_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_PRESENTATION_FORMS_B_ID: typing.ClassVar[int] = ...
        ARABIC_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARABIC_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        ARMENIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARMENIAN_ID: typing.ClassVar[int] = ...
        ARROWS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ARROWS_ID: typing.ClassVar[int] = ...
        AVESTAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        AVESTAN_ID: typing.ClassVar[int] = ...
        BALINESE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BALINESE_ID: typing.ClassVar[int] = ...
        BAMUM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BAMUM_ID: typing.ClassVar[int] = ...
        BAMUM_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BAMUM_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        BASIC_LATIN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BASIC_LATIN_ID: typing.ClassVar[int] = ...
        BASSA_VAH: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BASSA_VAH_ID: typing.ClassVar[int] = ...
        BATAK: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BATAK_ID: typing.ClassVar[int] = ...
        BENGALI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BENGALI_ID: typing.ClassVar[int] = ...
        BHAIKSUKI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BHAIKSUKI_ID: typing.ClassVar[int] = ...
        BLOCK_ELEMENTS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BLOCK_ELEMENTS_ID: typing.ClassVar[int] = ...
        BOPOMOFO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BOPOMOFO_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BOPOMOFO_EXTENDED_ID: typing.ClassVar[int] = ...
        BOPOMOFO_ID: typing.ClassVar[int] = ...
        BOX_DRAWING: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BOX_DRAWING_ID: typing.ClassVar[int] = ...
        BRAHMI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BRAHMI_ID: typing.ClassVar[int] = ...
        BRAILLE_PATTERNS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BRAILLE_PATTERNS_ID: typing.ClassVar[int] = ...
        BUGINESE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BUGINESE_ID: typing.ClassVar[int] = ...
        BUHID: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BUHID_ID: typing.ClassVar[int] = ...
        BYZANTINE_MUSICAL_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        BYZANTINE_MUSICAL_SYMBOLS_ID: typing.ClassVar[int] = ...
        CARIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CARIAN_ID: typing.ClassVar[int] = ...
        CAUCASIAN_ALBANIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CAUCASIAN_ALBANIAN_ID: typing.ClassVar[int] = ...
        CHAKMA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CHAKMA_ID: typing.ClassVar[int] = ...
        CHAM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CHAM_ID: typing.ClassVar[int] = ...
        CHEROKEE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CHEROKEE_ID: typing.ClassVar[int] = ...
        CHEROKEE_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CHEROKEE_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        CHESS_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CHESS_SYMBOLS_ID: typing.ClassVar[int] = ...
        CHORASMIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CHORASMIAN_ID: typing.ClassVar[int] = ...
        CJK_COMPATIBILITY: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_COMPATIBILITY_FORMS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_COMPATIBILITY_FORMS_ID: typing.ClassVar[int] = ...
        CJK_COMPATIBILITY_ID: typing.ClassVar[int] = ...
        CJK_COMPATIBILITY_IDEOGRAPHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_COMPATIBILITY_IDEOGRAPHS_ID: typing.ClassVar[int] = ...
        CJK_COMPATIBILITY_IDEOGRAPHS_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_COMPATIBILITY_IDEOGRAPHS_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        CJK_RADICALS_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_RADICALS_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        CJK_STROKES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_STROKES_ID: typing.ClassVar[int] = ...
        CJK_SYMBOLS_AND_PUNCTUATION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_SYMBOLS_AND_PUNCTUATION_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_A_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_B_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_D: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_D_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_E: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_E_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_F: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_F_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_G: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_G_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_H: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_H_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_I: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CJK_UNIFIED_IDEOGRAPHS_EXTENSION_I_ID: typing.ClassVar[int] = ...
        CJK_UNIFIED_IDEOGRAPHS_ID: typing.ClassVar[int] = ...
        COMBINING_DIACRITICAL_MARKS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COMBINING_DIACRITICAL_MARKS_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COMBINING_DIACRITICAL_MARKS_EXTENDED_ID: typing.ClassVar[int] = ...
        COMBINING_DIACRITICAL_MARKS_ID: typing.ClassVar[int] = ...
        COMBINING_DIACRITICAL_MARKS_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COMBINING_DIACRITICAL_MARKS_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        COMBINING_HALF_MARKS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COMBINING_HALF_MARKS_ID: typing.ClassVar[int] = ...
        COMBINING_MARKS_FOR_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COMBINING_MARKS_FOR_SYMBOLS_ID: typing.ClassVar[int] = ...
        COMMON_INDIC_NUMBER_FORMS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COMMON_INDIC_NUMBER_FORMS_ID: typing.ClassVar[int] = ...
        CONTROL_PICTURES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CONTROL_PICTURES_ID: typing.ClassVar[int] = ...
        COPTIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COPTIC_EPACT_NUMBERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COPTIC_EPACT_NUMBERS_ID: typing.ClassVar[int] = ...
        COPTIC_ID: typing.ClassVar[int] = ...
        COUNTING_ROD_NUMERALS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        COUNTING_ROD_NUMERALS_ID: typing.ClassVar[int] = ...
        CUNEIFORM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CUNEIFORM_ID: typing.ClassVar[int] = ...
        CUNEIFORM_NUMBERS_AND_PUNCTUATION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CUNEIFORM_NUMBERS_AND_PUNCTUATION_ID: typing.ClassVar[int] = ...
        CURRENCY_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CURRENCY_SYMBOLS_ID: typing.ClassVar[int] = ...
        CYPRIOT_SYLLABARY: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYPRIOT_SYLLABARY_ID: typing.ClassVar[int] = ...
        CYPRO_MINOAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYPRO_MINOAN_ID: typing.ClassVar[int] = ...
        CYRILLIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYRILLIC_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYRILLIC_EXTENDED_A_ID: typing.ClassVar[int] = ...
        CYRILLIC_EXTENDED_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYRILLIC_EXTENDED_B_ID: typing.ClassVar[int] = ...
        CYRILLIC_EXTENDED_C: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYRILLIC_EXTENDED_C_ID: typing.ClassVar[int] = ...
        CYRILLIC_EXTENDED_D: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYRILLIC_EXTENDED_D_ID: typing.ClassVar[int] = ...
        CYRILLIC_ID: typing.ClassVar[int] = ...
        CYRILLIC_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYRILLIC_SUPPLEMENTARY: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        CYRILLIC_SUPPLEMENTARY_ID: typing.ClassVar[int] = ...
        CYRILLIC_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        DESERET: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DESERET_ID: typing.ClassVar[int] = ...
        DEVANAGARI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DEVANAGARI_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DEVANAGARI_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DEVANAGARI_EXTENDED_A_ID: typing.ClassVar[int] = ...
        DEVANAGARI_EXTENDED_ID: typing.ClassVar[int] = ...
        DEVANAGARI_ID: typing.ClassVar[int] = ...
        DINGBATS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DINGBATS_ID: typing.ClassVar[int] = ...
        DIVES_AKURU: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DIVES_AKURU_ID: typing.ClassVar[int] = ...
        DOGRA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DOGRA_ID: typing.ClassVar[int] = ...
        DOMINO_TILES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DOMINO_TILES_ID: typing.ClassVar[int] = ...
        DUPLOYAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        DUPLOYAN_ID: typing.ClassVar[int] = ...
        EARLY_DYNASTIC_CUNEIFORM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        EARLY_DYNASTIC_CUNEIFORM_ID: typing.ClassVar[int] = ...
        EGYPTIAN_HIEROGLYPHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        EGYPTIAN_HIEROGLYPHS_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        EGYPTIAN_HIEROGLYPHS_EXTENDED_A_ID: typing.ClassVar[int] = ...
        EGYPTIAN_HIEROGLYPHS_ID: typing.ClassVar[int] = ...
        EGYPTIAN_HIEROGLYPH_FORMAT_CONTROLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        EGYPTIAN_HIEROGLYPH_FORMAT_CONTROLS_ID: typing.ClassVar[int] = ...
        ELBASAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ELBASAN_ID: typing.ClassVar[int] = ...
        ELYMAIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ELYMAIC_ID: typing.ClassVar[int] = ...
        EMOTICONS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        EMOTICONS_ID: typing.ClassVar[int] = ...
        ENCLOSED_ALPHANUMERICS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ENCLOSED_ALPHANUMERICS_ID: typing.ClassVar[int] = ...
        ENCLOSED_ALPHANUMERIC_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ENCLOSED_ALPHANUMERIC_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        ENCLOSED_CJK_LETTERS_AND_MONTHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ENCLOSED_CJK_LETTERS_AND_MONTHS_ID: typing.ClassVar[int] = ...
        ENCLOSED_IDEOGRAPHIC_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ENCLOSED_IDEOGRAPHIC_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        ETHIOPIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ETHIOPIC_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ETHIOPIC_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ETHIOPIC_EXTENDED_A_ID: typing.ClassVar[int] = ...
        ETHIOPIC_EXTENDED_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ETHIOPIC_EXTENDED_B_ID: typing.ClassVar[int] = ...
        ETHIOPIC_EXTENDED_ID: typing.ClassVar[int] = ...
        ETHIOPIC_ID: typing.ClassVar[int] = ...
        ETHIOPIC_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ETHIOPIC_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        GARAY: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GARAY_ID: typing.ClassVar[int] = ...
        GENERAL_PUNCTUATION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GENERAL_PUNCTUATION_ID: typing.ClassVar[int] = ...
        GEOMETRIC_SHAPES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GEOMETRIC_SHAPES_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GEOMETRIC_SHAPES_EXTENDED_ID: typing.ClassVar[int] = ...
        GEOMETRIC_SHAPES_ID: typing.ClassVar[int] = ...
        GEORGIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GEORGIAN_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GEORGIAN_EXTENDED_ID: typing.ClassVar[int] = ...
        GEORGIAN_ID: typing.ClassVar[int] = ...
        GEORGIAN_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GEORGIAN_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        GLAGOLITIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GLAGOLITIC_ID: typing.ClassVar[int] = ...
        GLAGOLITIC_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GLAGOLITIC_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        GOTHIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GOTHIC_ID: typing.ClassVar[int] = ...
        GRANTHA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GRANTHA_ID: typing.ClassVar[int] = ...
        GREEK: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GREEK_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GREEK_EXTENDED_ID: typing.ClassVar[int] = ...
        GREEK_ID: typing.ClassVar[int] = ...
        GUJARATI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GUJARATI_ID: typing.ClassVar[int] = ...
        GUNJALA_GONDI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GUNJALA_GONDI_ID: typing.ClassVar[int] = ...
        GURMUKHI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GURMUKHI_ID: typing.ClassVar[int] = ...
        GURUNG_KHEMA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        GURUNG_KHEMA_ID: typing.ClassVar[int] = ...
        HALFWIDTH_AND_FULLWIDTH_FORMS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HALFWIDTH_AND_FULLWIDTH_FORMS_ID: typing.ClassVar[int] = ...
        HANGUL_COMPATIBILITY_JAMO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HANGUL_COMPATIBILITY_JAMO_ID: typing.ClassVar[int] = ...
        HANGUL_JAMO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HANGUL_JAMO_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HANGUL_JAMO_EXTENDED_A_ID: typing.ClassVar[int] = ...
        HANGUL_JAMO_EXTENDED_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HANGUL_JAMO_EXTENDED_B_ID: typing.ClassVar[int] = ...
        HANGUL_JAMO_ID: typing.ClassVar[int] = ...
        HANGUL_SYLLABLES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HANGUL_SYLLABLES_ID: typing.ClassVar[int] = ...
        HANIFI_ROHINGYA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HANIFI_ROHINGYA_ID: typing.ClassVar[int] = ...
        HANUNOO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HANUNOO_ID: typing.ClassVar[int] = ...
        HATRAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HATRAN_ID: typing.ClassVar[int] = ...
        HEBREW: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HEBREW_ID: typing.ClassVar[int] = ...
        HIGH_PRIVATE_USE_SURROGATES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HIGH_PRIVATE_USE_SURROGATES_ID: typing.ClassVar[int] = ...
        HIGH_SURROGATES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HIGH_SURROGATES_ID: typing.ClassVar[int] = ...
        HIRAGANA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        HIRAGANA_ID: typing.ClassVar[int] = ...
        IDEOGRAPHIC_DESCRIPTION_CHARACTERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        IDEOGRAPHIC_DESCRIPTION_CHARACTERS_ID: typing.ClassVar[int] = ...
        IDEOGRAPHIC_SYMBOLS_AND_PUNCTUATION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        IDEOGRAPHIC_SYMBOLS_AND_PUNCTUATION_ID: typing.ClassVar[int] = ...
        IMPERIAL_ARAMAIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        IMPERIAL_ARAMAIC_ID: typing.ClassVar[int] = ...
        INDIC_SIYAQ_NUMBERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        INDIC_SIYAQ_NUMBERS_ID: typing.ClassVar[int] = ...
        INSCRIPTIONAL_PAHLAVI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        INSCRIPTIONAL_PAHLAVI_ID: typing.ClassVar[int] = ...
        INSCRIPTIONAL_PARTHIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        INSCRIPTIONAL_PARTHIAN_ID: typing.ClassVar[int] = ...
        INVALID_CODE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        INVALID_CODE_ID: typing.ClassVar[int] = ...
        IPA_EXTENSIONS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        IPA_EXTENSIONS_ID: typing.ClassVar[int] = ...
        JAVANESE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        JAVANESE_ID: typing.ClassVar[int] = ...
        KAITHI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KAITHI_ID: typing.ClassVar[int] = ...
        KAKTOVIK_NUMERALS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KAKTOVIK_NUMERALS_ID: typing.ClassVar[int] = ...
        KANA_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KANA_EXTENDED_A_ID: typing.ClassVar[int] = ...
        KANA_EXTENDED_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KANA_EXTENDED_B_ID: typing.ClassVar[int] = ...
        KANA_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KANA_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        KANBUN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KANBUN_ID: typing.ClassVar[int] = ...
        KANGXI_RADICALS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KANGXI_RADICALS_ID: typing.ClassVar[int] = ...
        KANNADA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KANNADA_ID: typing.ClassVar[int] = ...
        KATAKANA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KATAKANA_ID: typing.ClassVar[int] = ...
        KATAKANA_PHONETIC_EXTENSIONS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KATAKANA_PHONETIC_EXTENSIONS_ID: typing.ClassVar[int] = ...
        KAWI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KAWI_ID: typing.ClassVar[int] = ...
        KAYAH_LI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KAYAH_LI_ID: typing.ClassVar[int] = ...
        KHAROSHTHI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KHAROSHTHI_ID: typing.ClassVar[int] = ...
        KHITAN_SMALL_SCRIPT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KHITAN_SMALL_SCRIPT_ID: typing.ClassVar[int] = ...
        KHMER: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KHMER_ID: typing.ClassVar[int] = ...
        KHMER_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KHMER_SYMBOLS_ID: typing.ClassVar[int] = ...
        KHOJKI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KHOJKI_ID: typing.ClassVar[int] = ...
        KHUDAWADI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KHUDAWADI_ID: typing.ClassVar[int] = ...
        KIRAT_RAI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        KIRAT_RAI_ID: typing.ClassVar[int] = ...
        LAO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LAO_ID: typing.ClassVar[int] = ...
        LATIN_1_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_1_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_ADDITIONAL: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_ADDITIONAL_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_A_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_B_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_C: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_C_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_D: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_D_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_E: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_E_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_F: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_F_ID: typing.ClassVar[int] = ...
        LATIN_EXTENDED_G: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LATIN_EXTENDED_G_ID: typing.ClassVar[int] = ...
        LEPCHA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LEPCHA_ID: typing.ClassVar[int] = ...
        LETTERLIKE_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LETTERLIKE_SYMBOLS_ID: typing.ClassVar[int] = ...
        LIMBU: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LIMBU_ID: typing.ClassVar[int] = ...
        LINEAR_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LINEAR_A_ID: typing.ClassVar[int] = ...
        LINEAR_B_IDEOGRAMS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LINEAR_B_IDEOGRAMS_ID: typing.ClassVar[int] = ...
        LINEAR_B_SYLLABARY: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LINEAR_B_SYLLABARY_ID: typing.ClassVar[int] = ...
        LISU: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LISU_ID: typing.ClassVar[int] = ...
        LISU_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LISU_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        LOW_SURROGATES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LOW_SURROGATES_ID: typing.ClassVar[int] = ...
        LYCIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LYCIAN_ID: typing.ClassVar[int] = ...
        LYDIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        LYDIAN_ID: typing.ClassVar[int] = ...
        MAHAJANI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MAHAJANI_ID: typing.ClassVar[int] = ...
        MAHJONG_TILES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MAHJONG_TILES_ID: typing.ClassVar[int] = ...
        MAKASAR: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MAKASAR_ID: typing.ClassVar[int] = ...
        MALAYALAM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MALAYALAM_ID: typing.ClassVar[int] = ...
        MANDAIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MANDAIC_ID: typing.ClassVar[int] = ...
        MANICHAEAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MANICHAEAN_ID: typing.ClassVar[int] = ...
        MARCHEN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MARCHEN_ID: typing.ClassVar[int] = ...
        MASARAM_GONDI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MASARAM_GONDI_ID: typing.ClassVar[int] = ...
        MATHEMATICAL_ALPHANUMERIC_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MATHEMATICAL_ALPHANUMERIC_SYMBOLS_ID: typing.ClassVar[int] = ...
        MATHEMATICAL_OPERATORS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MATHEMATICAL_OPERATORS_ID: typing.ClassVar[int] = ...
        MAYAN_NUMERALS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MAYAN_NUMERALS_ID: typing.ClassVar[int] = ...
        MEDEFAIDRIN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MEDEFAIDRIN_ID: typing.ClassVar[int] = ...
        MEETEI_MAYEK: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MEETEI_MAYEK_EXTENSIONS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MEETEI_MAYEK_EXTENSIONS_ID: typing.ClassVar[int] = ...
        MEETEI_MAYEK_ID: typing.ClassVar[int] = ...
        MENDE_KIKAKUI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MENDE_KIKAKUI_ID: typing.ClassVar[int] = ...
        MEROITIC_CURSIVE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MEROITIC_CURSIVE_ID: typing.ClassVar[int] = ...
        MEROITIC_HIEROGLYPHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MEROITIC_HIEROGLYPHS_ID: typing.ClassVar[int] = ...
        MIAO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MIAO_ID: typing.ClassVar[int] = ...
        MISCELLANEOUS_MATHEMATICAL_SYMBOLS_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MISCELLANEOUS_MATHEMATICAL_SYMBOLS_A_ID: typing.ClassVar[int] = ...
        MISCELLANEOUS_MATHEMATICAL_SYMBOLS_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MISCELLANEOUS_MATHEMATICAL_SYMBOLS_B_ID: typing.ClassVar[int] = ...
        MISCELLANEOUS_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MISCELLANEOUS_SYMBOLS_AND_ARROWS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MISCELLANEOUS_SYMBOLS_AND_ARROWS_ID: typing.ClassVar[int] = ...
        MISCELLANEOUS_SYMBOLS_AND_PICTOGRAPHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MISCELLANEOUS_SYMBOLS_AND_PICTOGRAPHS_ID: typing.ClassVar[int] = ...
        MISCELLANEOUS_SYMBOLS_ID: typing.ClassVar[int] = ...
        MISCELLANEOUS_TECHNICAL: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MISCELLANEOUS_TECHNICAL_ID: typing.ClassVar[int] = ...
        MODI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MODIFIER_TONE_LETTERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MODIFIER_TONE_LETTERS_ID: typing.ClassVar[int] = ...
        MODI_ID: typing.ClassVar[int] = ...
        MONGOLIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MONGOLIAN_ID: typing.ClassVar[int] = ...
        MONGOLIAN_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MONGOLIAN_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        MRO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MRO_ID: typing.ClassVar[int] = ...
        MULTANI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MULTANI_ID: typing.ClassVar[int] = ...
        MUSICAL_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MUSICAL_SYMBOLS_ID: typing.ClassVar[int] = ...
        MYANMAR: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MYANMAR_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MYANMAR_EXTENDED_A_ID: typing.ClassVar[int] = ...
        MYANMAR_EXTENDED_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MYANMAR_EXTENDED_B_ID: typing.ClassVar[int] = ...
        MYANMAR_EXTENDED_C: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        MYANMAR_EXTENDED_C_ID: typing.ClassVar[int] = ...
        MYANMAR_ID: typing.ClassVar[int] = ...
        NABATAEAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NABATAEAN_ID: typing.ClassVar[int] = ...
        NAG_MUNDARI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NAG_MUNDARI_ID: typing.ClassVar[int] = ...
        NANDINAGARI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NANDINAGARI_ID: typing.ClassVar[int] = ...
        NEWA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NEWA_ID: typing.ClassVar[int] = ...
        NEW_TAI_LUE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NEW_TAI_LUE_ID: typing.ClassVar[int] = ...
        NKO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NKO_ID: typing.ClassVar[int] = ...
        NO_BLOCK: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NUMBER_FORMS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NUMBER_FORMS_ID: typing.ClassVar[int] = ...
        NUSHU: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NUSHU_ID: typing.ClassVar[int] = ...
        NYIAKENG_PUACHUE_HMONG: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        NYIAKENG_PUACHUE_HMONG_ID: typing.ClassVar[int] = ...
        OGHAM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OGHAM_ID: typing.ClassVar[int] = ...
        OLD_HUNGARIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_HUNGARIAN_ID: typing.ClassVar[int] = ...
        OLD_ITALIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_ITALIC_ID: typing.ClassVar[int] = ...
        OLD_NORTH_ARABIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_NORTH_ARABIAN_ID: typing.ClassVar[int] = ...
        OLD_PERMIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_PERMIC_ID: typing.ClassVar[int] = ...
        OLD_PERSIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_PERSIAN_ID: typing.ClassVar[int] = ...
        OLD_SOGDIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_SOGDIAN_ID: typing.ClassVar[int] = ...
        OLD_SOUTH_ARABIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_SOUTH_ARABIAN_ID: typing.ClassVar[int] = ...
        OLD_TURKIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_TURKIC_ID: typing.ClassVar[int] = ...
        OLD_UYGHUR: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OLD_UYGHUR_ID: typing.ClassVar[int] = ...
        OL_CHIKI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OL_CHIKI_ID: typing.ClassVar[int] = ...
        OL_ONAL: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OL_ONAL_ID: typing.ClassVar[int] = ...
        OPTICAL_CHARACTER_RECOGNITION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OPTICAL_CHARACTER_RECOGNITION_ID: typing.ClassVar[int] = ...
        ORIYA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ORIYA_ID: typing.ClassVar[int] = ...
        ORNAMENTAL_DINGBATS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ORNAMENTAL_DINGBATS_ID: typing.ClassVar[int] = ...
        OSAGE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OSAGE_ID: typing.ClassVar[int] = ...
        OSMANYA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OSMANYA_ID: typing.ClassVar[int] = ...
        OTTOMAN_SIYAQ_NUMBERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        OTTOMAN_SIYAQ_NUMBERS_ID: typing.ClassVar[int] = ...
        PAHAWH_HMONG: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PAHAWH_HMONG_ID: typing.ClassVar[int] = ...
        PALMYRENE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PALMYRENE_ID: typing.ClassVar[int] = ...
        PAU_CIN_HAU: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PAU_CIN_HAU_ID: typing.ClassVar[int] = ...
        PHAGS_PA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PHAGS_PA_ID: typing.ClassVar[int] = ...
        PHAISTOS_DISC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PHAISTOS_DISC_ID: typing.ClassVar[int] = ...
        PHOENICIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PHOENICIAN_ID: typing.ClassVar[int] = ...
        PHONETIC_EXTENSIONS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PHONETIC_EXTENSIONS_ID: typing.ClassVar[int] = ...
        PHONETIC_EXTENSIONS_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PHONETIC_EXTENSIONS_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        PLAYING_CARDS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PLAYING_CARDS_ID: typing.ClassVar[int] = ...
        PRIVATE_USE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PRIVATE_USE_AREA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PRIVATE_USE_AREA_ID: typing.ClassVar[int] = ...
        PRIVATE_USE_ID: typing.ClassVar[int] = ...
        PSALTER_PAHLAVI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        PSALTER_PAHLAVI_ID: typing.ClassVar[int] = ...
        REJANG: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        REJANG_ID: typing.ClassVar[int] = ...
        RUMI_NUMERAL_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        RUMI_NUMERAL_SYMBOLS_ID: typing.ClassVar[int] = ...
        RUNIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        RUNIC_ID: typing.ClassVar[int] = ...
        SAMARITAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SAMARITAN_ID: typing.ClassVar[int] = ...
        SAURASHTRA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SAURASHTRA_ID: typing.ClassVar[int] = ...
        SHARADA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SHARADA_ID: typing.ClassVar[int] = ...
        SHAVIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SHAVIAN_ID: typing.ClassVar[int] = ...
        SHORTHAND_FORMAT_CONTROLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SHORTHAND_FORMAT_CONTROLS_ID: typing.ClassVar[int] = ...
        SIDDHAM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SIDDHAM_ID: typing.ClassVar[int] = ...
        SINHALA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SINHALA_ARCHAIC_NUMBERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SINHALA_ARCHAIC_NUMBERS_ID: typing.ClassVar[int] = ...
        SINHALA_ID: typing.ClassVar[int] = ...
        SMALL_FORM_VARIANTS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SMALL_FORM_VARIANTS_ID: typing.ClassVar[int] = ...
        SMALL_KANA_EXTENSION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SMALL_KANA_EXTENSION_ID: typing.ClassVar[int] = ...
        SOGDIAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SOGDIAN_ID: typing.ClassVar[int] = ...
        SORA_SOMPENG: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SORA_SOMPENG_ID: typing.ClassVar[int] = ...
        SOYOMBO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SOYOMBO_ID: typing.ClassVar[int] = ...
        SPACING_MODIFIER_LETTERS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SPACING_MODIFIER_LETTERS_ID: typing.ClassVar[int] = ...
        SPECIALS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SPECIALS_ID: typing.ClassVar[int] = ...
        SUNDANESE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUNDANESE_ID: typing.ClassVar[int] = ...
        SUNDANESE_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUNDANESE_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        SUNUWAR: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUNUWAR_ID: typing.ClassVar[int] = ...
        SUPERSCRIPTS_AND_SUBSCRIPTS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPERSCRIPTS_AND_SUBSCRIPTS_ID: typing.ClassVar[int] = ...
        SUPPLEMENTAL_ARROWS_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTAL_ARROWS_A_ID: typing.ClassVar[int] = ...
        SUPPLEMENTAL_ARROWS_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTAL_ARROWS_B_ID: typing.ClassVar[int] = ...
        SUPPLEMENTAL_ARROWS_C: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTAL_ARROWS_C_ID: typing.ClassVar[int] = ...
        SUPPLEMENTAL_MATHEMATICAL_OPERATORS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTAL_MATHEMATICAL_OPERATORS_ID: typing.ClassVar[int] = ...
        SUPPLEMENTAL_PUNCTUATION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTAL_PUNCTUATION_ID: typing.ClassVar[int] = ...
        SUPPLEMENTAL_SYMBOLS_AND_PICTOGRAPHS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTAL_SYMBOLS_AND_PICTOGRAPHS_ID: typing.ClassVar[int] = ...
        SUPPLEMENTARY_PRIVATE_USE_AREA_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTARY_PRIVATE_USE_AREA_A_ID: typing.ClassVar[int] = ...
        SUPPLEMENTARY_PRIVATE_USE_AREA_B: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUPPLEMENTARY_PRIVATE_USE_AREA_B_ID: typing.ClassVar[int] = ...
        SUTTON_SIGNWRITING: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SUTTON_SIGNWRITING_ID: typing.ClassVar[int] = ...
        SYLOTI_NAGRI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SYLOTI_NAGRI_ID: typing.ClassVar[int] = ...
        SYMBOLS_AND_PICTOGRAPHS_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SYMBOLS_AND_PICTOGRAPHS_EXTENDED_A_ID: typing.ClassVar[int] = ...
        SYMBOLS_FOR_LEGACY_COMPUTING: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SYMBOLS_FOR_LEGACY_COMPUTING_ID: typing.ClassVar[int] = ...
        SYMBOLS_FOR_LEGACY_COMPUTING_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SYMBOLS_FOR_LEGACY_COMPUTING_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        SYRIAC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SYRIAC_ID: typing.ClassVar[int] = ...
        SYRIAC_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        SYRIAC_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        TAGALOG: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAGALOG_ID: typing.ClassVar[int] = ...
        TAGBANWA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAGBANWA_ID: typing.ClassVar[int] = ...
        TAGS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAGS_ID: typing.ClassVar[int] = ...
        TAI_LE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAI_LE_ID: typing.ClassVar[int] = ...
        TAI_THAM: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAI_THAM_ID: typing.ClassVar[int] = ...
        TAI_VIET: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAI_VIET_ID: typing.ClassVar[int] = ...
        TAI_XUAN_JING_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAI_XUAN_JING_SYMBOLS_ID: typing.ClassVar[int] = ...
        TAKRI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAKRI_ID: typing.ClassVar[int] = ...
        TAMIL: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAMIL_ID: typing.ClassVar[int] = ...
        TAMIL_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TAMIL_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        TANGSA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TANGSA_ID: typing.ClassVar[int] = ...
        TANGUT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TANGUT_COMPONENTS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TANGUT_COMPONENTS_ID: typing.ClassVar[int] = ...
        TANGUT_ID: typing.ClassVar[int] = ...
        TANGUT_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TANGUT_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        TELUGU: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TELUGU_ID: typing.ClassVar[int] = ...
        THAANA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        THAANA_ID: typing.ClassVar[int] = ...
        THAI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        THAI_ID: typing.ClassVar[int] = ...
        TIBETAN: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TIBETAN_ID: typing.ClassVar[int] = ...
        TIFINAGH: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TIFINAGH_ID: typing.ClassVar[int] = ...
        TIRHUTA: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TIRHUTA_ID: typing.ClassVar[int] = ...
        TODHRI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TODHRI_ID: typing.ClassVar[int] = ...
        TOTO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TOTO_ID: typing.ClassVar[int] = ...
        TRANSPORT_AND_MAP_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TRANSPORT_AND_MAP_SYMBOLS_ID: typing.ClassVar[int] = ...
        TULU_TIGALARI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        TULU_TIGALARI_ID: typing.ClassVar[int] = ...
        UGARITIC: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        UGARITIC_ID: typing.ClassVar[int] = ...
        UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED_A: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED_A_ID: typing.ClassVar[int] = ...
        UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED_ID: typing.ClassVar[int] = ...
        UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_ID: typing.ClassVar[int] = ...
        VAI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        VAI_ID: typing.ClassVar[int] = ...
        VARIATION_SELECTORS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        VARIATION_SELECTORS_ID: typing.ClassVar[int] = ...
        VARIATION_SELECTORS_SUPPLEMENT: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        VARIATION_SELECTORS_SUPPLEMENT_ID: typing.ClassVar[int] = ...
        VEDIC_EXTENSIONS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        VEDIC_EXTENSIONS_ID: typing.ClassVar[int] = ...
        VERTICAL_FORMS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        VERTICAL_FORMS_ID: typing.ClassVar[int] = ...
        VITHKUQI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        VITHKUQI_ID: typing.ClassVar[int] = ...
        WANCHO: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        WANCHO_ID: typing.ClassVar[int] = ...
        WARANG_CITI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        WARANG_CITI_ID: typing.ClassVar[int] = ...
        YEZIDI: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        YEZIDI_ID: typing.ClassVar[int] = ...
        YIJING_HEXAGRAM_SYMBOLS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        YIJING_HEXAGRAM_SYMBOLS_ID: typing.ClassVar[int] = ...
        YI_RADICALS: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        YI_RADICALS_ID: typing.ClassVar[int] = ...
        YI_SYLLABLES: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        YI_SYLLABLES_ID: typing.ClassVar[int] = ...
        ZANABAZAR_SQUARE: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ZANABAZAR_SQUARE_ID: typing.ClassVar[int] = ...
        ZNAMENNY_MUSICAL_NOTATION: typing.ClassVar[UCharacter.UnicodeBlock] = ...
        ZNAMENNY_MUSICAL_NOTATION_ID: typing.ClassVar[int] = ...
        @staticmethod
        def forName(blockName: str | java.lang.String, /) -> UCharacter.UnicodeBlock: ...
        def getID(self) -> int: ...
        @staticmethod
        def getInstance(id: int | java.jint | java.lang.Integer, /) -> UCharacter.UnicodeBlock: ...
        @staticmethod
        def of(ch: int | java.jint | java.lang.Integer, /) -> UCharacter.UnicodeBlock: ...

    class SentenceBreak(java.lang.Object):
        ATERM: typing.ClassVar[int] = ...
        CLOSE: typing.ClassVar[int] = ...
        CR: typing.ClassVar[int] = ...
        EXTEND: typing.ClassVar[int] = ...
        FORMAT: typing.ClassVar[int] = ...
        LF: typing.ClassVar[int] = ...
        LOWER: typing.ClassVar[int] = ...
        NUMERIC: typing.ClassVar[int] = ...
        OLETTER: typing.ClassVar[int] = ...
        OTHER: typing.ClassVar[int] = ...
        SCONTINUE: typing.ClassVar[int] = ...
        SEP: typing.ClassVar[int] = ...
        SP: typing.ClassVar[int] = ...
        STERM: typing.ClassVar[int] = ...
        UPPER: typing.ClassVar[int] = ...

    class NumericType(java.lang.Object):
        DECIMAL: typing.ClassVar[int] = ...
        DIGIT: typing.ClassVar[int] = ...
        NONE: typing.ClassVar[int] = ...
        NUMERIC: typing.ClassVar[int] = ...

    class LineBreak(java.lang.Object):
        AKSARA: typing.ClassVar[int] = ...
        AKSARA_PREBASE: typing.ClassVar[int] = ...
        AKSARA_START: typing.ClassVar[int] = ...
        ALPHABETIC: typing.ClassVar[int] = ...
        AMBIGUOUS: typing.ClassVar[int] = ...
        BREAK_AFTER: typing.ClassVar[int] = ...
        BREAK_BEFORE: typing.ClassVar[int] = ...
        BREAK_BOTH: typing.ClassVar[int] = ...
        BREAK_SYMBOLS: typing.ClassVar[int] = ...
        CARRIAGE_RETURN: typing.ClassVar[int] = ...
        CLOSE_PARENTHESIS: typing.ClassVar[int] = ...
        CLOSE_PUNCTUATION: typing.ClassVar[int] = ...
        COMBINING_MARK: typing.ClassVar[int] = ...
        COMPLEX_CONTEXT: typing.ClassVar[int] = ...
        CONDITIONAL_JAPANESE_STARTER: typing.ClassVar[int] = ...
        CONTINGENT_BREAK: typing.ClassVar[int] = ...
        EXCLAMATION: typing.ClassVar[int] = ...
        E_BASE: typing.ClassVar[int] = ...
        E_MODIFIER: typing.ClassVar[int] = ...
        GLUE: typing.ClassVar[int] = ...
        H2: typing.ClassVar[int] = ...
        H3: typing.ClassVar[int] = ...
        HEBREW_LETTER: typing.ClassVar[int] = ...
        HYPHEN: typing.ClassVar[int] = ...
        IDEOGRAPHIC: typing.ClassVar[int] = ...
        INFIX_NUMERIC: typing.ClassVar[int] = ...
        INSEPARABLE: typing.ClassVar[int] = ...
        INSEPERABLE: typing.ClassVar[int] = ...
        JL: typing.ClassVar[int] = ...
        JT: typing.ClassVar[int] = ...
        JV: typing.ClassVar[int] = ...
        LINE_FEED: typing.ClassVar[int] = ...
        MANDATORY_BREAK: typing.ClassVar[int] = ...
        NEXT_LINE: typing.ClassVar[int] = ...
        NONSTARTER: typing.ClassVar[int] = ...
        NUMERIC: typing.ClassVar[int] = ...
        OPEN_PUNCTUATION: typing.ClassVar[int] = ...
        POSTFIX_NUMERIC: typing.ClassVar[int] = ...
        PREFIX_NUMERIC: typing.ClassVar[int] = ...
        QUOTATION: typing.ClassVar[int] = ...
        REGIONAL_INDICATOR: typing.ClassVar[int] = ...
        SPACE: typing.ClassVar[int] = ...
        SURROGATE: typing.ClassVar[int] = ...
        UNKNOWN: typing.ClassVar[int] = ...
        VIRAMA: typing.ClassVar[int] = ...
        VIRAMA_FINAL: typing.ClassVar[int] = ...
        WORD_JOINER: typing.ClassVar[int] = ...
        ZWJ: typing.ClassVar[int] = ...
        ZWSPACE: typing.ClassVar[int] = ...

    class JoiningType(java.lang.Object):
        DUAL_JOINING: typing.ClassVar[int] = ...
        JOIN_CAUSING: typing.ClassVar[int] = ...
        LEFT_JOINING: typing.ClassVar[int] = ...
        NON_JOINING: typing.ClassVar[int] = ...
        RIGHT_JOINING: typing.ClassVar[int] = ...
        TRANSPARENT: typing.ClassVar[int] = ...

    class JoiningGroup(java.lang.Object):
        AFRICAN_FEH: typing.ClassVar[int] = ...
        AFRICAN_NOON: typing.ClassVar[int] = ...
        AFRICAN_QAF: typing.ClassVar[int] = ...
        AIN: typing.ClassVar[int] = ...
        ALAPH: typing.ClassVar[int] = ...
        ALEF: typing.ClassVar[int] = ...
        BEH: typing.ClassVar[int] = ...
        BETH: typing.ClassVar[int] = ...
        BURUSHASKI_YEH_BARREE: typing.ClassVar[int] = ...
        DAL: typing.ClassVar[int] = ...
        DALATH_RISH: typing.ClassVar[int] = ...
        E: typing.ClassVar[int] = ...
        FARSI_YEH: typing.ClassVar[int] = ...
        FE: typing.ClassVar[int] = ...
        FEH: typing.ClassVar[int] = ...
        FINAL_SEMKATH: typing.ClassVar[int] = ...
        GAF: typing.ClassVar[int] = ...
        GAMAL: typing.ClassVar[int] = ...
        HAH: typing.ClassVar[int] = ...
        HAMZA_ON_HEH_GOAL: typing.ClassVar[int] = ...
        HANIFI_ROHINGYA_KINNA_YA: typing.ClassVar[int] = ...
        HANIFI_ROHINGYA_PA: typing.ClassVar[int] = ...
        HE: typing.ClassVar[int] = ...
        HEH: typing.ClassVar[int] = ...
        HEH_GOAL: typing.ClassVar[int] = ...
        HETH: typing.ClassVar[int] = ...
        KAF: typing.ClassVar[int] = ...
        KAPH: typing.ClassVar[int] = ...
        KASHMIRI_YEH: typing.ClassVar[int] = ...
        KHAPH: typing.ClassVar[int] = ...
        KNOTTED_HEH: typing.ClassVar[int] = ...
        LAM: typing.ClassVar[int] = ...
        LAMADH: typing.ClassVar[int] = ...
        MALAYALAM_BHA: typing.ClassVar[int] = ...
        MALAYALAM_JA: typing.ClassVar[int] = ...
        MALAYALAM_LLA: typing.ClassVar[int] = ...
        MALAYALAM_LLLA: typing.ClassVar[int] = ...
        MALAYALAM_NGA: typing.ClassVar[int] = ...
        MALAYALAM_NNA: typing.ClassVar[int] = ...
        MALAYALAM_NNNA: typing.ClassVar[int] = ...
        MALAYALAM_NYA: typing.ClassVar[int] = ...
        MALAYALAM_RA: typing.ClassVar[int] = ...
        MALAYALAM_SSA: typing.ClassVar[int] = ...
        MALAYALAM_TTA: typing.ClassVar[int] = ...
        MANICHAEAN_ALEPH: typing.ClassVar[int] = ...
        MANICHAEAN_AYIN: typing.ClassVar[int] = ...
        MANICHAEAN_BETH: typing.ClassVar[int] = ...
        MANICHAEAN_DALETH: typing.ClassVar[int] = ...
        MANICHAEAN_DHAMEDH: typing.ClassVar[int] = ...
        MANICHAEAN_FIVE: typing.ClassVar[int] = ...
        MANICHAEAN_GIMEL: typing.ClassVar[int] = ...
        MANICHAEAN_HETH: typing.ClassVar[int] = ...
        MANICHAEAN_HUNDRED: typing.ClassVar[int] = ...
        MANICHAEAN_KAPH: typing.ClassVar[int] = ...
        MANICHAEAN_LAMEDH: typing.ClassVar[int] = ...
        MANICHAEAN_MEM: typing.ClassVar[int] = ...
        MANICHAEAN_NUN: typing.ClassVar[int] = ...
        MANICHAEAN_ONE: typing.ClassVar[int] = ...
        MANICHAEAN_PE: typing.ClassVar[int] = ...
        MANICHAEAN_QOPH: typing.ClassVar[int] = ...
        MANICHAEAN_RESH: typing.ClassVar[int] = ...
        MANICHAEAN_SADHE: typing.ClassVar[int] = ...
        MANICHAEAN_SAMEKH: typing.ClassVar[int] = ...
        MANICHAEAN_TAW: typing.ClassVar[int] = ...
        MANICHAEAN_TEN: typing.ClassVar[int] = ...
        MANICHAEAN_TETH: typing.ClassVar[int] = ...
        MANICHAEAN_THAMEDH: typing.ClassVar[int] = ...
        MANICHAEAN_TWENTY: typing.ClassVar[int] = ...
        MANICHAEAN_WAW: typing.ClassVar[int] = ...
        MANICHAEAN_YODH: typing.ClassVar[int] = ...
        MANICHAEAN_ZAYIN: typing.ClassVar[int] = ...
        MEEM: typing.ClassVar[int] = ...
        MIM: typing.ClassVar[int] = ...
        NOON: typing.ClassVar[int] = ...
        NO_JOINING_GROUP: typing.ClassVar[int] = ...
        NUN: typing.ClassVar[int] = ...
        NYA: typing.ClassVar[int] = ...
        PE: typing.ClassVar[int] = ...
        QAF: typing.ClassVar[int] = ...
        QAPH: typing.ClassVar[int] = ...
        REH: typing.ClassVar[int] = ...
        REVERSED_PE: typing.ClassVar[int] = ...
        ROHINGYA_YEH: typing.ClassVar[int] = ...
        SAD: typing.ClassVar[int] = ...
        SADHE: typing.ClassVar[int] = ...
        SEEN: typing.ClassVar[int] = ...
        SEMKATH: typing.ClassVar[int] = ...
        SHIN: typing.ClassVar[int] = ...
        STRAIGHT_WAW: typing.ClassVar[int] = ...
        SWASH_KAF: typing.ClassVar[int] = ...
        SYRIAC_WAW: typing.ClassVar[int] = ...
        TAH: typing.ClassVar[int] = ...
        TAW: typing.ClassVar[int] = ...
        TEH_MARBUTA: typing.ClassVar[int] = ...
        TEH_MARBUTA_GOAL: typing.ClassVar[int] = ...
        TETH: typing.ClassVar[int] = ...
        THIN_YEH: typing.ClassVar[int] = ...
        VERTICAL_TAIL: typing.ClassVar[int] = ...
        WAW: typing.ClassVar[int] = ...
        YEH: typing.ClassVar[int] = ...
        YEH_BARREE: typing.ClassVar[int] = ...
        YEH_WITH_TAIL: typing.ClassVar[int] = ...
        YUDH: typing.ClassVar[int] = ...
        YUDH_HE: typing.ClassVar[int] = ...
        ZAIN: typing.ClassVar[int] = ...
        ZHAIN: typing.ClassVar[int] = ...

    class IndicSyllabicCategory(java.lang.Object):
        AVAGRAHA: typing.ClassVar[int] = ...
        BINDU: typing.ClassVar[int] = ...
        BRAHMI_JOINING_NUMBER: typing.ClassVar[int] = ...
        CANTILLATION_MARK: typing.ClassVar[int] = ...
        CONSONANT: typing.ClassVar[int] = ...
        CONSONANT_DEAD: typing.ClassVar[int] = ...
        CONSONANT_FINAL: typing.ClassVar[int] = ...
        CONSONANT_HEAD_LETTER: typing.ClassVar[int] = ...
        CONSONANT_INITIAL_POSTFIXED: typing.ClassVar[int] = ...
        CONSONANT_KILLER: typing.ClassVar[int] = ...
        CONSONANT_MEDIAL: typing.ClassVar[int] = ...
        CONSONANT_PLACEHOLDER: typing.ClassVar[int] = ...
        CONSONANT_PRECEDING_REPHA: typing.ClassVar[int] = ...
        CONSONANT_PREFIXED: typing.ClassVar[int] = ...
        CONSONANT_SUBJOINED: typing.ClassVar[int] = ...
        CONSONANT_SUCCEEDING_REPHA: typing.ClassVar[int] = ...
        CONSONANT_WITH_STACKER: typing.ClassVar[int] = ...
        GEMINATION_MARK: typing.ClassVar[int] = ...
        INVISIBLE_STACKER: typing.ClassVar[int] = ...
        JOINER: typing.ClassVar[int] = ...
        MODIFYING_LETTER: typing.ClassVar[int] = ...
        NON_JOINER: typing.ClassVar[int] = ...
        NUKTA: typing.ClassVar[int] = ...
        NUMBER: typing.ClassVar[int] = ...
        NUMBER_JOINER: typing.ClassVar[int] = ...
        OTHER: typing.ClassVar[int] = ...
        PURE_KILLER: typing.ClassVar[int] = ...
        REGISTER_SHIFTER: typing.ClassVar[int] = ...
        REORDERING_KILLER: typing.ClassVar[int] = ...
        SYLLABLE_MODIFIER: typing.ClassVar[int] = ...
        TONE_LETTER: typing.ClassVar[int] = ...
        TONE_MARK: typing.ClassVar[int] = ...
        VIRAMA: typing.ClassVar[int] = ...
        VISARGA: typing.ClassVar[int] = ...
        VOWEL: typing.ClassVar[int] = ...
        VOWEL_DEPENDENT: typing.ClassVar[int] = ...
        VOWEL_INDEPENDENT: typing.ClassVar[int] = ...

    class IndicPositionalCategory(java.lang.Object):
        BOTTOM: typing.ClassVar[int] = ...
        BOTTOM_AND_LEFT: typing.ClassVar[int] = ...
        BOTTOM_AND_RIGHT: typing.ClassVar[int] = ...
        LEFT: typing.ClassVar[int] = ...
        LEFT_AND_RIGHT: typing.ClassVar[int] = ...
        NA: typing.ClassVar[int] = ...
        OVERSTRUCK: typing.ClassVar[int] = ...
        RIGHT: typing.ClassVar[int] = ...
        TOP: typing.ClassVar[int] = ...
        TOP_AND_BOTTOM: typing.ClassVar[int] = ...
        TOP_AND_BOTTOM_AND_LEFT: typing.ClassVar[int] = ...
        TOP_AND_BOTTOM_AND_RIGHT: typing.ClassVar[int] = ...
        TOP_AND_LEFT: typing.ClassVar[int] = ...
        TOP_AND_LEFT_AND_RIGHT: typing.ClassVar[int] = ...
        TOP_AND_RIGHT: typing.ClassVar[int] = ...
        VISUAL_ORDER_LEFT: typing.ClassVar[int] = ...

    class HangulSyllableType(java.lang.Object):
        LEADING_JAMO: typing.ClassVar[int] = ...
        LVT_SYLLABLE: typing.ClassVar[int] = ...
        LV_SYLLABLE: typing.ClassVar[int] = ...
        NOT_APPLICABLE: typing.ClassVar[int] = ...
        TRAILING_JAMO: typing.ClassVar[int] = ...
        VOWEL_JAMO: typing.ClassVar[int] = ...

    class GraphemeClusterBreak(java.lang.Object):
        CONTROL: typing.ClassVar[int] = ...
        CR: typing.ClassVar[int] = ...
        EXTEND: typing.ClassVar[int] = ...
        E_BASE: typing.ClassVar[int] = ...
        E_BASE_GAZ: typing.ClassVar[int] = ...
        E_MODIFIER: typing.ClassVar[int] = ...
        GLUE_AFTER_ZWJ: typing.ClassVar[int] = ...
        L: typing.ClassVar[int] = ...
        LF: typing.ClassVar[int] = ...
        LV: typing.ClassVar[int] = ...
        LVT: typing.ClassVar[int] = ...
        OTHER: typing.ClassVar[int] = ...
        PREPEND: typing.ClassVar[int] = ...
        REGIONAL_INDICATOR: typing.ClassVar[int] = ...
        SPACING_MARK: typing.ClassVar[int] = ...
        T: typing.ClassVar[int] = ...
        V: typing.ClassVar[int] = ...
        ZWJ: typing.ClassVar[int] = ...

    class EastAsianWidth(java.lang.Object):
        AMBIGUOUS: typing.ClassVar[int] = ...
        FULLWIDTH: typing.ClassVar[int] = ...
        HALFWIDTH: typing.ClassVar[int] = ...
        NARROW: typing.ClassVar[int] = ...
        NEUTRAL: typing.ClassVar[int] = ...
        WIDE: typing.ClassVar[int] = ...

    class DecompositionType(java.lang.Object):
        CANONICAL: typing.ClassVar[int] = ...
        CIRCLE: typing.ClassVar[int] = ...
        COMPAT: typing.ClassVar[int] = ...
        FINAL: typing.ClassVar[int] = ...
        FONT: typing.ClassVar[int] = ...
        FRACTION: typing.ClassVar[int] = ...
        INITIAL: typing.ClassVar[int] = ...
        ISOLATED: typing.ClassVar[int] = ...
        MEDIAL: typing.ClassVar[int] = ...
        NARROW: typing.ClassVar[int] = ...
        NOBREAK: typing.ClassVar[int] = ...
        NONE: typing.ClassVar[int] = ...
        SMALL: typing.ClassVar[int] = ...
        SQUARE: typing.ClassVar[int] = ...
        SUB: typing.ClassVar[int] = ...
        SUPER: typing.ClassVar[int] = ...
        VERTICAL: typing.ClassVar[int] = ...
        WIDE: typing.ClassVar[int] = ...

    class BidiPairedBracketType(java.lang.Object):
        CLOSE: typing.ClassVar[int] = ...
        NONE: typing.ClassVar[int] = ...
        OPEN: typing.ClassVar[int] = ...

class UCharacterCategory(UCharacterEnums.ECharacterCategory):
    @staticmethod
    def toString(category: int | java.jint | java.lang.Integer, /) -> str: ...

class UCharacterDirection(UCharacterEnums.ECharacterDirection):
    @staticmethod
    def toString(dir: int | java.jint | java.lang.Integer, /) -> str: ...

class UCharacterEnums(java.lang.Object):

    class ECharacterDirection(java.lang.Object):
        ARABIC_NUMBER: typing.ClassVar[int] = ...
        BLOCK_SEPARATOR: typing.ClassVar[int] = ...
        BOUNDARY_NEUTRAL: typing.ClassVar[int] = ...
        COMMON_NUMBER_SEPARATOR: typing.ClassVar[int] = ...
        DIRECTIONALITY_ARABIC_NUMBER: typing.ClassVar[int] = ...
        DIRECTIONALITY_BOUNDARY_NEUTRAL: typing.ClassVar[int] = ...
        DIRECTIONALITY_COMMON_NUMBER_SEPARATOR: typing.ClassVar[int] = ...
        DIRECTIONALITY_EUROPEAN_NUMBER: typing.ClassVar[int] = ...
        DIRECTIONALITY_EUROPEAN_NUMBER_SEPARATOR: typing.ClassVar[int] = ...
        DIRECTIONALITY_EUROPEAN_NUMBER_TERMINATOR: typing.ClassVar[int] = ...
        DIRECTIONALITY_LEFT_TO_RIGHT: typing.ClassVar[int] = ...
        DIRECTIONALITY_LEFT_TO_RIGHT_EMBEDDING: typing.ClassVar[int] = ...
        DIRECTIONALITY_LEFT_TO_RIGHT_OVERRIDE: typing.ClassVar[int] = ...
        DIRECTIONALITY_NONSPACING_MARK: typing.ClassVar[int] = ...
        DIRECTIONALITY_OTHER_NEUTRALS: typing.ClassVar[int] = ...
        DIRECTIONALITY_PARAGRAPH_SEPARATOR: typing.ClassVar[int] = ...
        DIRECTIONALITY_POP_DIRECTIONAL_FORMAT: typing.ClassVar[int] = ...
        DIRECTIONALITY_RIGHT_TO_LEFT: typing.ClassVar[int] = ...
        DIRECTIONALITY_RIGHT_TO_LEFT_ARABIC: typing.ClassVar[int] = ...
        DIRECTIONALITY_RIGHT_TO_LEFT_EMBEDDING: typing.ClassVar[int] = ...
        DIRECTIONALITY_RIGHT_TO_LEFT_OVERRIDE: typing.ClassVar[int] = ...
        DIRECTIONALITY_SEGMENT_SEPARATOR: typing.ClassVar[int] = ...
        DIRECTIONALITY_UNDEFINED: typing.ClassVar[int] = ...
        DIRECTIONALITY_WHITESPACE: typing.ClassVar[int] = ...
        DIR_NON_SPACING_MARK: typing.ClassVar[int] = ...
        EUROPEAN_NUMBER: typing.ClassVar[int] = ...
        EUROPEAN_NUMBER_SEPARATOR: typing.ClassVar[int] = ...
        EUROPEAN_NUMBER_TERMINATOR: typing.ClassVar[int] = ...
        FIRST_STRONG_ISOLATE: typing.ClassVar[int] = ...
        LEFT_TO_RIGHT: typing.ClassVar[int] = ...
        LEFT_TO_RIGHT_EMBEDDING: typing.ClassVar[int] = ...
        LEFT_TO_RIGHT_ISOLATE: typing.ClassVar[int] = ...
        LEFT_TO_RIGHT_OVERRIDE: typing.ClassVar[int] = ...
        OTHER_NEUTRAL: typing.ClassVar[int] = ...
        POP_DIRECTIONAL_FORMAT: typing.ClassVar[int] = ...
        POP_DIRECTIONAL_ISOLATE: typing.ClassVar[int] = ...
        RIGHT_TO_LEFT: typing.ClassVar[int] = ...
        RIGHT_TO_LEFT_ARABIC: typing.ClassVar[int] = ...
        RIGHT_TO_LEFT_EMBEDDING: typing.ClassVar[int] = ...
        RIGHT_TO_LEFT_ISOLATE: typing.ClassVar[int] = ...
        RIGHT_TO_LEFT_OVERRIDE: typing.ClassVar[int] = ...
        SEGMENT_SEPARATOR: typing.ClassVar[int] = ...
        WHITE_SPACE_NEUTRAL: typing.ClassVar[int] = ...

    class ECharacterCategory(java.lang.Object):
        COMBINING_SPACING_MARK: typing.ClassVar[int] = ...
        CONNECTOR_PUNCTUATION: typing.ClassVar[int] = ...
        CONTROL: typing.ClassVar[int] = ...
        CURRENCY_SYMBOL: typing.ClassVar[int] = ...
        DASH_PUNCTUATION: typing.ClassVar[int] = ...
        DECIMAL_DIGIT_NUMBER: typing.ClassVar[int] = ...
        ENCLOSING_MARK: typing.ClassVar[int] = ...
        END_PUNCTUATION: typing.ClassVar[int] = ...
        FINAL_PUNCTUATION: typing.ClassVar[int] = ...
        FINAL_QUOTE_PUNCTUATION: typing.ClassVar[int] = ...
        FORMAT: typing.ClassVar[int] = ...
        GENERAL_OTHER_TYPES: typing.ClassVar[int] = ...
        INITIAL_PUNCTUATION: typing.ClassVar[int] = ...
        INITIAL_QUOTE_PUNCTUATION: typing.ClassVar[int] = ...
        LETTER_NUMBER: typing.ClassVar[int] = ...
        LINE_SEPARATOR: typing.ClassVar[int] = ...
        LOWERCASE_LETTER: typing.ClassVar[int] = ...
        MATH_SYMBOL: typing.ClassVar[int] = ...
        MODIFIER_LETTER: typing.ClassVar[int] = ...
        MODIFIER_SYMBOL: typing.ClassVar[int] = ...
        NON_SPACING_MARK: typing.ClassVar[int] = ...
        OTHER_LETTER: typing.ClassVar[int] = ...
        OTHER_NUMBER: typing.ClassVar[int] = ...
        OTHER_PUNCTUATION: typing.ClassVar[int] = ...
        OTHER_SYMBOL: typing.ClassVar[int] = ...
        PARAGRAPH_SEPARATOR: typing.ClassVar[int] = ...
        PRIVATE_USE: typing.ClassVar[int] = ...
        SPACE_SEPARATOR: typing.ClassVar[int] = ...
        START_PUNCTUATION: typing.ClassVar[int] = ...
        SURROGATE: typing.ClassVar[int] = ...
        TITLECASE_LETTER: typing.ClassVar[int] = ...
        UNASSIGNED: typing.ClassVar[int] = ...
        UPPERCASE_LETTER: typing.ClassVar[int] = ...

class UProperty(java.lang.Object):
    AGE: typing.ClassVar[int] = ...
    ALPHABETIC: typing.ClassVar[int] = ...
    ASCII_HEX_DIGIT: typing.ClassVar[int] = ...
    BASIC_EMOJI: typing.ClassVar[int] = ...
    BIDI_CLASS: typing.ClassVar[int] = ...
    BIDI_CONTROL: typing.ClassVar[int] = ...
    BIDI_MIRRORED: typing.ClassVar[int] = ...
    BIDI_MIRRORING_GLYPH: typing.ClassVar[int] = ...
    BIDI_PAIRED_BRACKET: typing.ClassVar[int] = ...
    BIDI_PAIRED_BRACKET_TYPE: typing.ClassVar[int] = ...
    BINARY_START: typing.ClassVar[int] = ...
    BLOCK: typing.ClassVar[int] = ...
    CANONICAL_COMBINING_CLASS: typing.ClassVar[int] = ...
    CASED: typing.ClassVar[int] = ...
    CASE_FOLDING: typing.ClassVar[int] = ...
    CASE_IGNORABLE: typing.ClassVar[int] = ...
    CASE_SENSITIVE: typing.ClassVar[int] = ...
    CHANGES_WHEN_CASEFOLDED: typing.ClassVar[int] = ...
    CHANGES_WHEN_CASEMAPPED: typing.ClassVar[int] = ...
    CHANGES_WHEN_LOWERCASED: typing.ClassVar[int] = ...
    CHANGES_WHEN_NFKC_CASEFOLDED: typing.ClassVar[int] = ...
    CHANGES_WHEN_TITLECASED: typing.ClassVar[int] = ...
    CHANGES_WHEN_UPPERCASED: typing.ClassVar[int] = ...
    DASH: typing.ClassVar[int] = ...
    DECOMPOSITION_TYPE: typing.ClassVar[int] = ...
    DEFAULT_IGNORABLE_CODE_POINT: typing.ClassVar[int] = ...
    DEPRECATED: typing.ClassVar[int] = ...
    DIACRITIC: typing.ClassVar[int] = ...
    DOUBLE_START: typing.ClassVar[int] = ...
    EAST_ASIAN_WIDTH: typing.ClassVar[int] = ...
    EMOJI: typing.ClassVar[int] = ...
    EMOJI_COMPONENT: typing.ClassVar[int] = ...
    EMOJI_KEYCAP_SEQUENCE: typing.ClassVar[int] = ...
    EMOJI_MODIFIER: typing.ClassVar[int] = ...
    EMOJI_MODIFIER_BASE: typing.ClassVar[int] = ...
    EMOJI_PRESENTATION: typing.ClassVar[int] = ...
    EXTENDED_PICTOGRAPHIC: typing.ClassVar[int] = ...
    EXTENDER: typing.ClassVar[int] = ...
    FULL_COMPOSITION_EXCLUSION: typing.ClassVar[int] = ...
    GENERAL_CATEGORY: typing.ClassVar[int] = ...
    GENERAL_CATEGORY_MASK: typing.ClassVar[int] = ...
    GRAPHEME_BASE: typing.ClassVar[int] = ...
    GRAPHEME_CLUSTER_BREAK: typing.ClassVar[int] = ...
    GRAPHEME_EXTEND: typing.ClassVar[int] = ...
    GRAPHEME_LINK: typing.ClassVar[int] = ...
    HANGUL_SYLLABLE_TYPE: typing.ClassVar[int] = ...
    HEX_DIGIT: typing.ClassVar[int] = ...
    HYPHEN: typing.ClassVar[int] = ...
    IDEOGRAPHIC: typing.ClassVar[int] = ...
    IDS_BINARY_OPERATOR: typing.ClassVar[int] = ...
    IDS_TRINARY_OPERATOR: typing.ClassVar[int] = ...
    IDS_UNARY_OPERATOR: typing.ClassVar[int] = ...
    ID_COMPAT_MATH_CONTINUE: typing.ClassVar[int] = ...
    ID_COMPAT_MATH_START: typing.ClassVar[int] = ...
    ID_CONTINUE: typing.ClassVar[int] = ...
    ID_START: typing.ClassVar[int] = ...
    INDIC_POSITIONAL_CATEGORY: typing.ClassVar[int] = ...
    INDIC_SYLLABIC_CATEGORY: typing.ClassVar[int] = ...
    INT_START: typing.ClassVar[int] = ...
    JOINING_GROUP: typing.ClassVar[int] = ...
    JOINING_TYPE: typing.ClassVar[int] = ...
    JOIN_CONTROL: typing.ClassVar[int] = ...
    LEAD_CANONICAL_COMBINING_CLASS: typing.ClassVar[int] = ...
    LINE_BREAK: typing.ClassVar[int] = ...
    LOGICAL_ORDER_EXCEPTION: typing.ClassVar[int] = ...
    LOWERCASE: typing.ClassVar[int] = ...
    LOWERCASE_MAPPING: typing.ClassVar[int] = ...
    MASK_START: typing.ClassVar[int] = ...
    MATH: typing.ClassVar[int] = ...
    NAME: typing.ClassVar[int] = ...
    NFC_INERT: typing.ClassVar[int] = ...
    NFC_QUICK_CHECK: typing.ClassVar[int] = ...
    NFD_INERT: typing.ClassVar[int] = ...
    NFD_QUICK_CHECK: typing.ClassVar[int] = ...
    NFKC_INERT: typing.ClassVar[int] = ...
    NFKC_QUICK_CHECK: typing.ClassVar[int] = ...
    NFKD_INERT: typing.ClassVar[int] = ...
    NFKD_QUICK_CHECK: typing.ClassVar[int] = ...
    NONCHARACTER_CODE_POINT: typing.ClassVar[int] = ...
    NUMERIC_TYPE: typing.ClassVar[int] = ...
    NUMERIC_VALUE: typing.ClassVar[int] = ...
    OTHER_PROPERTY_START: typing.ClassVar[int] = ...
    PATTERN_SYNTAX: typing.ClassVar[int] = ...
    PATTERN_WHITE_SPACE: typing.ClassVar[int] = ...
    POSIX_ALNUM: typing.ClassVar[int] = ...
    POSIX_BLANK: typing.ClassVar[int] = ...
    POSIX_GRAPH: typing.ClassVar[int] = ...
    POSIX_PRINT: typing.ClassVar[int] = ...
    POSIX_XDIGIT: typing.ClassVar[int] = ...
    PREPENDED_CONCATENATION_MARK: typing.ClassVar[int] = ...
    QUOTATION_MARK: typing.ClassVar[int] = ...
    RADICAL: typing.ClassVar[int] = ...
    REGIONAL_INDICATOR: typing.ClassVar[int] = ...
    RGI_EMOJI: typing.ClassVar[int] = ...
    RGI_EMOJI_FLAG_SEQUENCE: typing.ClassVar[int] = ...
    RGI_EMOJI_MODIFIER_SEQUENCE: typing.ClassVar[int] = ...
    RGI_EMOJI_TAG_SEQUENCE: typing.ClassVar[int] = ...
    RGI_EMOJI_ZWJ_SEQUENCE: typing.ClassVar[int] = ...
    SCRIPT: typing.ClassVar[int] = ...
    SCRIPT_EXTENSIONS: typing.ClassVar[int] = ...
    SEGMENT_STARTER: typing.ClassVar[int] = ...
    SENTENCE_BREAK: typing.ClassVar[int] = ...
    SIMPLE_CASE_FOLDING: typing.ClassVar[int] = ...
    SIMPLE_LOWERCASE_MAPPING: typing.ClassVar[int] = ...
    SIMPLE_TITLECASE_MAPPING: typing.ClassVar[int] = ...
    SIMPLE_UPPERCASE_MAPPING: typing.ClassVar[int] = ...
    SOFT_DOTTED: typing.ClassVar[int] = ...
    STRING_START: typing.ClassVar[int] = ...
    S_TERM: typing.ClassVar[int] = ...
    TERMINAL_PUNCTUATION: typing.ClassVar[int] = ...
    TITLECASE_MAPPING: typing.ClassVar[int] = ...
    TRAIL_CANONICAL_COMBINING_CLASS: typing.ClassVar[int] = ...
    UNIFIED_IDEOGRAPH: typing.ClassVar[int] = ...
    UPPERCASE: typing.ClassVar[int] = ...
    UPPERCASE_MAPPING: typing.ClassVar[int] = ...
    VARIATION_SELECTOR: typing.ClassVar[int] = ...
    VERTICAL_ORIENTATION: typing.ClassVar[int] = ...
    WHITE_SPACE: typing.ClassVar[int] = ...
    WORD_BREAK: typing.ClassVar[int] = ...
    XID_CONTINUE: typing.ClassVar[int] = ...
    XID_START: typing.ClassVar[int] = ...

    class NameChoice(java.lang.Object):
        LONG: typing.ClassVar[int] = ...
        SHORT: typing.ClassVar[int] = ...

class UScript(java.lang.Object):
    ADLAM: typing.ClassVar[int] = ...
    AFAKA: typing.ClassVar[int] = ...
    AHOM: typing.ClassVar[int] = ...
    ANATOLIAN_HIEROGLYPHS: typing.ClassVar[int] = ...
    ARABIC: typing.ClassVar[int] = ...
    ARABIC_NASTALIQ: typing.ClassVar[int] = ...
    ARMENIAN: typing.ClassVar[int] = ...
    AVESTAN: typing.ClassVar[int] = ...
    BALINESE: typing.ClassVar[int] = ...
    BAMUM: typing.ClassVar[int] = ...
    BASSA_VAH: typing.ClassVar[int] = ...
    BATAK: typing.ClassVar[int] = ...
    BENGALI: typing.ClassVar[int] = ...
    BHAIKSUKI: typing.ClassVar[int] = ...
    BLISSYMBOLS: typing.ClassVar[int] = ...
    BOOK_PAHLAVI: typing.ClassVar[int] = ...
    BOPOMOFO: typing.ClassVar[int] = ...
    BRAHMI: typing.ClassVar[int] = ...
    BRAILLE: typing.ClassVar[int] = ...
    BUGINESE: typing.ClassVar[int] = ...
    BUHID: typing.ClassVar[int] = ...
    CANADIAN_ABORIGINAL: typing.ClassVar[int] = ...
    CARIAN: typing.ClassVar[int] = ...
    CAUCASIAN_ALBANIAN: typing.ClassVar[int] = ...
    CHAKMA: typing.ClassVar[int] = ...
    CHAM: typing.ClassVar[int] = ...
    CHEROKEE: typing.ClassVar[int] = ...
    CHORASMIAN: typing.ClassVar[int] = ...
    CIRTH: typing.ClassVar[int] = ...
    COMMON: typing.ClassVar[int] = ...
    COPTIC: typing.ClassVar[int] = ...
    CUNEIFORM: typing.ClassVar[int] = ...
    CYPRIOT: typing.ClassVar[int] = ...
    CYPRO_MINOAN: typing.ClassVar[int] = ...
    CYRILLIC: typing.ClassVar[int] = ...
    DEMOTIC_EGYPTIAN: typing.ClassVar[int] = ...
    DESERET: typing.ClassVar[int] = ...
    DEVANAGARI: typing.ClassVar[int] = ...
    DIVES_AKURU: typing.ClassVar[int] = ...
    DOGRA: typing.ClassVar[int] = ...
    DUPLOYAN: typing.ClassVar[int] = ...
    EASTERN_SYRIAC: typing.ClassVar[int] = ...
    EGYPTIAN_HIEROGLYPHS: typing.ClassVar[int] = ...
    ELBASAN: typing.ClassVar[int] = ...
    ELYMAIC: typing.ClassVar[int] = ...
    ESTRANGELO_SYRIAC: typing.ClassVar[int] = ...
    ETHIOPIC: typing.ClassVar[int] = ...
    GARAY: typing.ClassVar[int] = ...
    GEORGIAN: typing.ClassVar[int] = ...
    GLAGOLITIC: typing.ClassVar[int] = ...
    GOTHIC: typing.ClassVar[int] = ...
    GRANTHA: typing.ClassVar[int] = ...
    GREEK: typing.ClassVar[int] = ...
    GUJARATI: typing.ClassVar[int] = ...
    GUNJALA_GONDI: typing.ClassVar[int] = ...
    GURMUKHI: typing.ClassVar[int] = ...
    GURUNG_KHEMA: typing.ClassVar[int] = ...
    HAN: typing.ClassVar[int] = ...
    HANGUL: typing.ClassVar[int] = ...
    HANIFI_ROHINGYA: typing.ClassVar[int] = ...
    HANUNOO: typing.ClassVar[int] = ...
    HAN_WITH_BOPOMOFO: typing.ClassVar[int] = ...
    HARAPPAN_INDUS: typing.ClassVar[int] = ...
    HATRAN: typing.ClassVar[int] = ...
    HEBREW: typing.ClassVar[int] = ...
    HIERATIC_EGYPTIAN: typing.ClassVar[int] = ...
    HIRAGANA: typing.ClassVar[int] = ...
    IMPERIAL_ARAMAIC: typing.ClassVar[int] = ...
    INHERITED: typing.ClassVar[int] = ...
    INSCRIPTIONAL_PAHLAVI: typing.ClassVar[int] = ...
    INSCRIPTIONAL_PARTHIAN: typing.ClassVar[int] = ...
    INVALID_CODE: typing.ClassVar[int] = ...
    JAMO: typing.ClassVar[int] = ...
    JAPANESE: typing.ClassVar[int] = ...
    JAVANESE: typing.ClassVar[int] = ...
    JURCHEN: typing.ClassVar[int] = ...
    KAITHI: typing.ClassVar[int] = ...
    KANNADA: typing.ClassVar[int] = ...
    KATAKANA: typing.ClassVar[int] = ...
    KATAKANA_OR_HIRAGANA: typing.ClassVar[int] = ...
    KAWI: typing.ClassVar[int] = ...
    KAYAH_LI: typing.ClassVar[int] = ...
    KHAROSHTHI: typing.ClassVar[int] = ...
    KHITAN_SMALL_SCRIPT: typing.ClassVar[int] = ...
    KHMER: typing.ClassVar[int] = ...
    KHOJKI: typing.ClassVar[int] = ...
    KHUDAWADI: typing.ClassVar[int] = ...
    KHUTSURI: typing.ClassVar[int] = ...
    KIRAT_RAI: typing.ClassVar[int] = ...
    KOREAN: typing.ClassVar[int] = ...
    KPELLE: typing.ClassVar[int] = ...
    LANNA: typing.ClassVar[int] = ...
    LAO: typing.ClassVar[int] = ...
    LATIN: typing.ClassVar[int] = ...
    LATIN_FRAKTUR: typing.ClassVar[int] = ...
    LATIN_GAELIC: typing.ClassVar[int] = ...
    LEPCHA: typing.ClassVar[int] = ...
    LIMBU: typing.ClassVar[int] = ...
    LINEAR_A: typing.ClassVar[int] = ...
    LINEAR_B: typing.ClassVar[int] = ...
    LISU: typing.ClassVar[int] = ...
    LOMA: typing.ClassVar[int] = ...
    LYCIAN: typing.ClassVar[int] = ...
    LYDIAN: typing.ClassVar[int] = ...
    MAHAJANI: typing.ClassVar[int] = ...
    MAKASAR: typing.ClassVar[int] = ...
    MALAYALAM: typing.ClassVar[int] = ...
    MANDAEAN: typing.ClassVar[int] = ...
    MANDAIC: typing.ClassVar[int] = ...
    MANICHAEAN: typing.ClassVar[int] = ...
    MARCHEN: typing.ClassVar[int] = ...
    MASARAM_GONDI: typing.ClassVar[int] = ...
    MATHEMATICAL_NOTATION: typing.ClassVar[int] = ...
    MAYAN_HIEROGLYPHS: typing.ClassVar[int] = ...
    MEDEFAIDRIN: typing.ClassVar[int] = ...
    MEITEI_MAYEK: typing.ClassVar[int] = ...
    MENDE: typing.ClassVar[int] = ...
    MEROITIC: typing.ClassVar[int] = ...
    MEROITIC_CURSIVE: typing.ClassVar[int] = ...
    MEROITIC_HIEROGLYPHS: typing.ClassVar[int] = ...
    MIAO: typing.ClassVar[int] = ...
    MODI: typing.ClassVar[int] = ...
    MONGOLIAN: typing.ClassVar[int] = ...
    MOON: typing.ClassVar[int] = ...
    MRO: typing.ClassVar[int] = ...
    MULTANI: typing.ClassVar[int] = ...
    MYANMAR: typing.ClassVar[int] = ...
    NABATAEAN: typing.ClassVar[int] = ...
    NAG_MUNDARI: typing.ClassVar[int] = ...
    NAKHI_GEBA: typing.ClassVar[int] = ...
    NANDINAGARI: typing.ClassVar[int] = ...
    NEWA: typing.ClassVar[int] = ...
    NEW_TAI_LUE: typing.ClassVar[int] = ...
    NKO: typing.ClassVar[int] = ...
    NUSHU: typing.ClassVar[int] = ...
    NYIAKENG_PUACHUE_HMONG: typing.ClassVar[int] = ...
    OGHAM: typing.ClassVar[int] = ...
    OLD_CHURCH_SLAVONIC_CYRILLIC: typing.ClassVar[int] = ...
    OLD_HUNGARIAN: typing.ClassVar[int] = ...
    OLD_ITALIC: typing.ClassVar[int] = ...
    OLD_NORTH_ARABIAN: typing.ClassVar[int] = ...
    OLD_PERMIC: typing.ClassVar[int] = ...
    OLD_PERSIAN: typing.ClassVar[int] = ...
    OLD_SOGDIAN: typing.ClassVar[int] = ...
    OLD_SOUTH_ARABIAN: typing.ClassVar[int] = ...
    OLD_UYGHUR: typing.ClassVar[int] = ...
    OL_CHIKI: typing.ClassVar[int] = ...
    OL_ONAL: typing.ClassVar[int] = ...
    ORIYA: typing.ClassVar[int] = ...
    ORKHON: typing.ClassVar[int] = ...
    OSAGE: typing.ClassVar[int] = ...
    OSMANYA: typing.ClassVar[int] = ...
    PAHAWH_HMONG: typing.ClassVar[int] = ...
    PALMYRENE: typing.ClassVar[int] = ...
    PAU_CIN_HAU: typing.ClassVar[int] = ...
    PHAGS_PA: typing.ClassVar[int] = ...
    PHOENICIAN: typing.ClassVar[int] = ...
    PHONETIC_POLLARD: typing.ClassVar[int] = ...
    PSALTER_PAHLAVI: typing.ClassVar[int] = ...
    REJANG: typing.ClassVar[int] = ...
    RONGORONGO: typing.ClassVar[int] = ...
    RUNIC: typing.ClassVar[int] = ...
    SAMARITAN: typing.ClassVar[int] = ...
    SARATI: typing.ClassVar[int] = ...
    SAURASHTRA: typing.ClassVar[int] = ...
    SHARADA: typing.ClassVar[int] = ...
    SHAVIAN: typing.ClassVar[int] = ...
    SIDDHAM: typing.ClassVar[int] = ...
    SIGN_WRITING: typing.ClassVar[int] = ...
    SIMPLIFIED_HAN: typing.ClassVar[int] = ...
    SINDHI: typing.ClassVar[int] = ...
    SINHALA: typing.ClassVar[int] = ...
    SOGDIAN: typing.ClassVar[int] = ...
    SORA_SOMPENG: typing.ClassVar[int] = ...
    SOYOMBO: typing.ClassVar[int] = ...
    SUNDANESE: typing.ClassVar[int] = ...
    SUNUWAR: typing.ClassVar[int] = ...
    SYLOTI_NAGRI: typing.ClassVar[int] = ...
    SYMBOLS: typing.ClassVar[int] = ...
    SYMBOLS_EMOJI: typing.ClassVar[int] = ...
    SYRIAC: typing.ClassVar[int] = ...
    TAGALOG: typing.ClassVar[int] = ...
    TAGBANWA: typing.ClassVar[int] = ...
    TAI_LE: typing.ClassVar[int] = ...
    TAI_VIET: typing.ClassVar[int] = ...
    TAKRI: typing.ClassVar[int] = ...
    TAMIL: typing.ClassVar[int] = ...
    TANGSA: typing.ClassVar[int] = ...
    TANGUT: typing.ClassVar[int] = ...
    TELUGU: typing.ClassVar[int] = ...
    TENGWAR: typing.ClassVar[int] = ...
    THAANA: typing.ClassVar[int] = ...
    THAI: typing.ClassVar[int] = ...
    TIBETAN: typing.ClassVar[int] = ...
    TIFINAGH: typing.ClassVar[int] = ...
    TIRHUTA: typing.ClassVar[int] = ...
    TODHRI: typing.ClassVar[int] = ...
    TOTO: typing.ClassVar[int] = ...
    TRADITIONAL_HAN: typing.ClassVar[int] = ...
    TULU_TIGALARI: typing.ClassVar[int] = ...
    UCAS: typing.ClassVar[int] = ...
    UGARITIC: typing.ClassVar[int] = ...
    UNKNOWN: typing.ClassVar[int] = ...
    UNWRITTEN_LANGUAGES: typing.ClassVar[int] = ...
    VAI: typing.ClassVar[int] = ...
    VISIBLE_SPEECH: typing.ClassVar[int] = ...
    VITHKUQI: typing.ClassVar[int] = ...
    WANCHO: typing.ClassVar[int] = ...
    WARANG_CITI: typing.ClassVar[int] = ...
    WESTERN_SYRIAC: typing.ClassVar[int] = ...
    WOLEAI: typing.ClassVar[int] = ...
    YEZIDI: typing.ClassVar[int] = ...
    YI: typing.ClassVar[int] = ...
    ZANABAZAR_SQUARE: typing.ClassVar[int] = ...
    @staticmethod
    def breaksBetweenLetters(script: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def getCode(locale: android.icu.util.ULocale, /) -> java.chaquopy.JavaArrayJInt | None: ...
    @typing.overload
    @staticmethod
    def getCode(nameOrAbbrOrLocale: str | java.lang.String, /) -> java.chaquopy.JavaArrayJInt | None: ...
    @typing.overload
    @staticmethod
    def getCode(locale: java.util.Locale, /) -> java.chaquopy.JavaArrayJInt | None: ...
    @staticmethod
    def getCodeFromName(nameOrAbbr: str | java.lang.String, /) -> int: ...
    @staticmethod
    def getName(scriptCode: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getSampleString(script: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getScript(codepoint: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getScriptExtensions(c: int | java.jint | java.lang.Integer, set: java.util.BitSet, /) -> int: ...
    @staticmethod
    def getShortName(scriptCode: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getUsage(script: int | java.jint | java.lang.Integer, /) -> UScript.ScriptUsage: ...
    @staticmethod
    def hasScript(c: int | java.jint | java.lang.Integer, sc: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isCased(script: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isRightToLeft(script: int | java.jint | java.lang.Integer, /) -> bool: ...

    class ScriptUsage(java.lang.Enum[UScript.ScriptUsage]):
        ASPIRATIONAL: typing.ClassVar[UScript.ScriptUsage] = ...
        EXCLUDED: typing.ClassVar[UScript.ScriptUsage] = ...
        LIMITED_USE: typing.ClassVar[UScript.ScriptUsage] = ...
        NOT_ENCODED: typing.ClassVar[UScript.ScriptUsage] = ...
        RECOMMENDED: typing.ClassVar[UScript.ScriptUsage] = ...
        UNKNOWN: typing.ClassVar[UScript.ScriptUsage] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> UScript.ScriptUsage: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[UScript.ScriptUsage]: ...



import typing

import android.content
import android.graphics
import android.os
import android.service.autofill
import android.util
import android.view
import java
import java.chaquopy
import java.lang
import java.util

class AutofillId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AutofillId]] = ...
    @staticmethod
    def create(host: android.view.View, virtualId: int | java.jint | java.lang.Integer, /) -> AutofillId: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAutofillVirtualId(self) -> int: ...
    def getSessionId(self) -> int: ...
    def getViewId(self) -> int: ...
    def hashCode(self) -> int: ...
    def isInAutofillSession(self) -> bool: ...
    def isVirtual(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AutofillManager(java.lang.Object):
    EXTRA_ASSIST_STRUCTURE: typing.ClassVar[str] = ...
    EXTRA_AUTHENTICATION_RESULT: typing.ClassVar[str] = ...
    EXTRA_AUTHENTICATION_RESULT_EPHEMERAL_DATASET: typing.ClassVar[str] = ...
    EXTRA_CLIENT_STATE: typing.ClassVar[str] = ...
    EXTRA_INLINE_SUGGESTIONS_REQUEST: typing.ClassVar[str] = ...
    def cancel(self) -> None: ...
    def commit(self) -> None: ...
    def disableAutofillServices(self) -> None: ...
    def getAutofillServiceComponentName(self) -> android.content.ComponentName | None: ...
    def getAvailableFieldClassificationAlgorithms(self) -> java.util.List[java.lang.String]: ...
    def getDefaultFieldClassificationAlgorithm(self) -> str | None: ...
    def getNextAutofillId(self) -> AutofillId | None: ...
    def getUserData(self) -> android.service.autofill.UserData | None: ...
    def getUserDataId(self) -> str | None: ...
    def hasEnabledAutofillServices(self) -> bool: ...
    def isAutofillSupported(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isFieldClassificationEnabled(self) -> bool: ...
    @typing.overload
    def notifyValueChanged(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def notifyValueChanged(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, value: AutofillValue, /) -> None: ...
    @typing.overload
    def notifyViewClicked(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def notifyViewClicked(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def notifyViewEntered(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def notifyViewEntered(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, absBounds: android.graphics.Rect, /) -> None: ...
    @typing.overload
    def notifyViewExited(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def notifyViewExited(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def notifyViewVisibilityChanged(self, view: android.view.View, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def notifyViewVisibilityChanged(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def notifyVirtualViewsReady(self, view: android.view.View, infos: android.util.SparseArray[VirtualViewFillInfo], /) -> None: ...
    def registerCallback(self, callback: AutofillManager.AutofillCallback, /) -> None: ...
    @typing.overload
    def requestAutofill(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def requestAutofill(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, absBounds: android.graphics.Rect, /) -> None: ...
    def setUserData(self, userData: android.service.autofill.UserData, /) -> None: ...
    @typing.overload
    def showAutofillDialog(self, view: android.view.View, /) -> bool: ...
    @typing.overload
    def showAutofillDialog(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def unregisterCallback(self, callback: AutofillManager.AutofillCallback, /) -> None: ...

    class AutofillCallback(java.lang.Object):
        EVENT_INPUT_HIDDEN: typing.ClassVar[int] = ...
        EVENT_INPUT_SHOWN: typing.ClassVar[int] = ...
        EVENT_INPUT_UNAVAILABLE: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        @typing.overload
        def onAutofillEvent(self, view: android.view.View, event: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def onAutofillEvent(self, view: android.view.View, virtualId: int | java.jint | java.lang.Integer, event: int | java.jint | java.lang.Integer, /) -> None: ...

class AutofillValue(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AutofillValue]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def forDate(value: int | java.jlong | java.lang.Long, /) -> AutofillValue: ...
    @staticmethod
    def forList(value: int | java.jint | java.lang.Integer, /) -> AutofillValue: ...
    @staticmethod
    def forText(value: java.lang.CharSequence, /) -> AutofillValue: ...
    @staticmethod
    def forToggle(value: bool | java.jboolean | java.lang.Boolean, /) -> AutofillValue: ...
    def getDateValue(self) -> int: ...
    def getListValue(self) -> int: ...
    def getTextValue(self) -> java.lang.CharSequence: ...
    def getToggleValue(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDate(self) -> bool: ...
    def isList(self) -> bool: ...
    def isText(self) -> bool: ...
    def isToggle(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VirtualViewFillInfo(java.lang.Object):
    def getAutofillHints(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> VirtualViewFillInfo: ...
        def setAutofillHints(self, *value: java.lang.String) -> VirtualViewFillInfo.Builder: ...
